Example of kmesh_generator — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

Note

Go to the end to download the full example code.

# Example of kmesh_generator

This utility can be used to generate a 2D \(k\)-mesh centered at a given \(k\)-point and in a given \(k\)-plane. This is particularly useful in computing 2D spin-textures and plotting 2D Fermi-surfaces. For example, the following command creates a 2D \(k_{x}\)-\(k_{y}\) -mesh centered at the \(\Gamma\) point (\(k_{z}= 0\)) ranging from coordinates (-0.5, -0.5, 0.0) to (0.5, 0.5, 0.0) with 5 grids in the x direction and 7 grids in the y direction

General Format

    pyprocar.generate2dkmesh(x1,y1,x2,y2,z,num_grids_x,num_grids_y)

This information is automatically written to a KPOINTS file.

    # sphinx_gallery_thumbnail_number = 1

## Plotting Kmesh

    import pyvista
    # You do not need this. This is to ensure an image is rendered off screen when generating exmaple gallery.
    pyvista.OFF_SCREEN = True

importing pyprocar and specifying local data_dir

    import os
    import pyprocar

    kpoints = pyprocar.generate2dkmesh(-0.5,-0.5,0.5,0.5,0,5,7)

    plotter=pyvista.Plotter()
    plotter.add_mesh(kpoints, color='blue', render_points_as_spheres=True, point_size=20)
    plotter.show_axes()
    plotter.show_grid()
    plotter.show()

     ____        ____
    |  _ \ _   _|  _ \ _ __ ___   ___ __ _ _ __
    | |_) | | | | |_) | '__/ _ \ / __/ _` | '__|
    |  __/| |_| |  __/| | | (_) | (_| (_| | |
    |_|    \__, |_|   |_|  \___/ \___\__,_|_|
           |___/
    A Python library for electronic structure pre/post-processing.

    Version 6.3.2 created on Jun 10th, 2021

    Please cite:
     Uthpala Herath, Pedram Tavadze, Xu He, Eric Bousquet, Sobhit Singh, Francisco Muñoz and Aldo Romero.,
     PyProcar: A Python library for electronic structure pre/post-processing.,
     Computer Physics Communications 251 (2020):107080.

    Developers:
    - Francisco Muñoz
    - Aldo Romero
    - Sobhit Singh
    - Uthpala Herath
    - Pedram Tavadze
    - Eric Bousquet
    - Xu He
    - Reese Boucher
    - Logan Lang
    - Freddy Farah

Total running time of the script: (0 minutes 0.380 seconds)

Gallery generated by Sphinx-Gallery